@@ -20,11 +20,11 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001-2004
 #include <kiconloader.h>
 
 // KDE includes
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdeconfig.h>
 
 // Project includes
 #include "../core/netfilterobject.h"
@@ -39,7 +39,7 @@ Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2001-2004
 #include "../kmyfirewall.h"
 #include "kmflistviewitem.h"
 namespace KMF {
-KMFListView::KMFListView( TQWidget *parent, const char *name ) : KListView( parent, name ) {
+KMFListView::KMFListView( TQWidget *parent, const char *name ) : TDEListView( parent, name ) {
 	loadIcons();
 	connect( this, TQT_SIGNAL( sigLoadNode( NetfilterObject* ) ),
 	         this, TQT_SLOT( slotLoadNode( NetfilterObject* ) ) );
@@ -56,8 +56,8 @@ KMFListView::KMFListView( TQWidget *parent, const char *name ) : KListView( pare
 	addColumn( i18n( "Value" ) );
 	setSizePolicy( TQSizePolicy( ( TQSizePolicy::SizeType ) 2, ( TQSizePolicy::SizeType ) 2, 0, 0,
 	                                  sizePolicy().hasHeightForWidth() ) );
-	setFrameShape( KListView::StyledPanel );
-	setFrameShadow( KListView::Sunken );
+	setFrameShape( TDEListView::StyledPanel );
+	setFrameShadow( TDEListView::Sunken );
 	setSorting( 0, true );
 	setFullWidth( true );
 	setItemsMovable( true );
@@ -1062,83 +1062,83 @@ KMFListViewItem* KMFListView::findKMFItem( const TQString & text1, int column1,c
 
 void KMFListView::loadIcons() {
 	kdDebug() << "void KMFListView::loadIcons()" << endl;
-	KIconLoader *loader = KGlobal::iconLoader();
+	TDEIconLoader *loader = TDEGlobal::iconLoader();
 	TQString icon_name;
 
-	icon_name = "up";
-	icon_up = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "go-up";
+	icon_up = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "down";
-	icon_down = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "go-down";
+	icon_down = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "ereaser";
-	icon_del = loader->loadIcon( icon_name, KIcon::Small );
+	icon_del = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "filenew";
-	icon_new = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "document-new";
+	icon_new = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "edit";
-	icon_edit = loader->loadIcon( icon_name, KIcon::Small );
+	icon_edit = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "rule";
-	icon_rule = loader->loadIcon( icon_name, KIcon::Small );
+	icon_rule = loader->loadIcon( icon_name, TDEIcon::Small );
 	
 	icon_name = "user_defined";
-	icon_user = loader->loadIcon( icon_name, KIcon::Small );
+	icon_user = loader->loadIcon( icon_name, TDEIcon::Small );
 	
 	icon_name = "builtin";
-	icon_builtin = loader->loadIcon( icon_name, KIcon::Small );
+	icon_builtin = loader->loadIcon( icon_name, TDEIcon::Small );
 	
 	icon_name = "table";
-	icon_table = loader->loadIcon( icon_name, KIcon::Small );
+	icon_table = loader->loadIcon( icon_name, TDEIcon::Small );
 	
 	icon_name = "filter";
-	icon_filter = loader->loadIcon( icon_name, KIcon::Small );
+	icon_filter = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "text";
-	icon_rename = loader->loadIcon( icon_name, KIcon::Small );
+	icon_rename = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "view_tree";
-	icon_chain = loader->loadIcon( icon_name, KIcon::Small );
+	icon_chain = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "reject";
-	icon_reject = loader->loadIcon( icon_name, KIcon::User );
+	icon_reject = loader->loadIcon( icon_name, TDEIcon::User );
 
 	icon_name = "target";
-	icon_target = loader->loadIcon( icon_name, KIcon::User );
+	icon_target = loader->loadIcon( icon_name, TDEIcon::User );
 
-	icon_name = "stop";
-	icon_drop = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "process-stop";
+	icon_drop = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "button_ok";
-	icon_accept = loader->loadIcon( icon_name, KIcon::Small );
+	icon_accept = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "filesaveas";
-	icon_log = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "document-save-as";
+	icon_log = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "undo";
-	icon_return = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-undo";
+	icon_return = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "editclear";
-	icon_cmd = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-clear";
+	icon_cmd = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "filter";
-	icon_filter = loader->loadIcon( icon_name, KIcon::Small );
+	icon_filter = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "pipe";
-	icon_queue = loader->loadIcon( icon_name, KIcon::Small );
+	icon_queue = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "button_cancel";
-	icon_disabled = loader->loadIcon( icon_name, KIcon::Small );
+	icon_disabled = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "1rightarrow";
-	icon_fwd = loader->loadIcon( icon_name, KIcon::Small );
+	icon_fwd = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "2rightarrow";
-	icon_fwds = loader->loadIcon( icon_name, KIcon::Small );
+	icon_fwds = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "fill";
-	icon_feed = loader->loadIcon( icon_name, KIcon::Small );
+	icon_feed = loader->loadIcon( icon_name, TDEIcon::Small );
 
 }
 
